import os

os.environ['TF_CPP_MIN_LOG_LEVEL']='3'

import numpy as np
import tensorflow as tf
from tensorflow import keras
import matplotlib.pyplot as plt
import cyclefinder as cycf
from sklearn.model_selection import train_test_split
from sklearn.metrics import f1_score
from sklearn import metrics
from sklearn.metrics import RocCurveDisplay
import scipy.io
from keras import backend as K
import random 


DTYPE='float32'
tf.keras.backend.set_floatx(DTYPE)
N_mu=4374
N_variation=7
N_time=550

U_RCCA=np.zeros([N_variation,4374,N_time])
U_LCCA=np.zeros([N_variation,4374,N_time])
U_RVA=np.zeros([N_variation,4374,N_time])
U_LVA=np.zeros([N_variation,4374,N_time])
for i in range(0,7):
    name1='Sample/U_RCCA'+str(i+1)+'.npy'
    name2='Sample/U_LCCA'+str(i+1)+'.npy'
    name3='Sample/U_RVA'+str(i+1)+'.npy'
    name4='Sample/U_LVA'+str(i+1)+'.npy'
    RCCA=np.load(name1,allow_pickle=True)
    LCCA=np.load(name2,allow_pickle=True)
    RVA=np.load(name3,allow_pickle=True)
    LVA=np.load(name4,allow_pickle=True)
    for j in range(0,4374):
        U_RCCA[i,j,:len(RCCA[j])]=RCCA[j][:,0]
        U_RCCA[i,j,len(RCCA[j]):]=RCCA[j][:N_time-len(RCCA[j]),0]
        U_LCCA[i,j,:len(LCCA[j])]=LCCA[j][:,0]
        U_LCCA[i,j,len(LCCA[j]):]=LCCA[j][:N_time-len(LCCA[j]),0]
        U_RVA[i,j,:len(RVA[j])]=RVA[j][:,0]
        U_RVA[i,j,len(RVA[j]):]=RVA[j][:N_time-len(RVA[j]),0]
        U_LVA[i,j,:len(LVA[j])]=LVA[j][:,0]
        U_LVA[i,j,len(LVA[j]):]=LVA[j][:N_time-len(LVA[j]),0]



X=np.zeros((N_mu*N_variation,N_time,4))
Y=np.zeros((N_mu*N_variation,N_variation))


X_input=np.zeros((N_mu*N_variation,N_time,2))
for i in range(0,7):               
    for j in range(0,N_mu):
        X_input[j+i*N_mu,:,0]=U_RCCA[i,j,:]
        X_input[j+i*N_mu,:,1]=U_LCCA[i,j,:]
        X_input[j+i*N_mu,:,1]=U_RVA[i,j,:]
        X_input[j+i*N_mu,:,3]=U_LVA[i,j,:]
        Y[j+i*N_mu,i]=1





x_train, x_test, y_train, y_test = train_test_split(X_input[:,::2,:], Y, test_size=0.2 )



pre=[0]
x_train_noise=np.zeros((x_train.shape[0],x_train.shape[1],x_train.shape[2]))
x_test_noise=np.zeros((x_test.shape[0],x_test.shape[1],x_test.shape[2]))

sample=x_train_noise.shape[1]
for j in range(0,4):
    for i in range(0,len(x_train)):
        amp=np.max(x_train[i,:,j])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        x_train_noise[i,:,j]=x_train[i,:,j]+noise
      
for j in range(0,4):
    for i in range(0,len(x_test)):
        amp=np.max(x_test[i,:,j])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        x_test_noise[i,:,j]=x_test[i,:,j]+noise
        

#### model and training #####    
model = tf.keras.Sequential()
# convolutional layer

model.add(tf.keras.layers.Conv1D(10, kernel_size=3, activation='relu', input_shape=(x_train.shape[1],x_train.shape[2])))
model.add(tf.keras.layers.Conv1D(10, kernel_size=3, activation='relu'))
model.add(tf.keras.layers.MaxPool1D(pool_size=2))

model.add(tf.keras.layers.Conv1D(10, kernel_size=3, activation='relu'))
model.add(tf.keras.layers.Conv1D(10, kernel_size=3, activation='relu'))
model.add(tf.keras.layers.MaxPool1D(pool_size=2))
   

# flatten output of conv
model.add(tf.keras.layers.Flatten())
# hidden layer
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
# output layer
model.add(tf.keras.layers.Dense(y_train.shape[1], activation='Softmax',name='Prediction'))



def recall_m(y_true, y_pred):
    true_positives = K.sum(K.round(K.clip(y_true * y_pred, 0, 1)))
    possible_positives = K.sum(K.round(K.clip(y_true, 0, 1)))
    recall = true_positives / (possible_positives + K.epsilon())
    return recall

def precision_m(y_true, y_pred):
    true_positives = K.sum(K.round(K.clip(y_true * y_pred, 0, 1)))
    predicted_positives = K.sum(K.round(K.clip(y_pred, 0, 1)))
    precision = true_positives / (predicted_positives + K.epsilon())
    return precision

def f1_m(y_true, y_pred):
    precision = precision_m(y_true, y_pred)
    recall = recall_m(y_true, y_pred)
    return 2*((precision*recall)/(precision+recall+K.epsilon()))



class CustomCallback(keras.callbacks.Callback):
    def on_epoch_end(self, epoch, logs=None):
        if logs.get('accuracy')>=0.99:
            self.model.stop_training = True
            
model.compile(loss='BinaryCrossentropy', metrics=[f1_m], optimizer='adam')

model.fit(x_train_noise, y_train, batch_size=1024, epochs=1000,verbose=2)



import shap
x_test_noise=x_test_noise[:300]
#explainer = shap.DeepExplainer(model, x_train[:1000])
#shap_values = explainer.shap_values(X_test)
shap_values=np.load('CNN_SHAP.npy')
wave=0
shap_values0=np.abs(shap_values[0][:,:,wave]).mean(0)
shap_values1=np.abs(shap_values[1][:,:,wave]).mean(0)
shap_values2=np.abs(shap_values[2][:,:,wave]).mean(0)
shap_values3=np.abs(shap_values[3][:,:,wave]).mean(0)
shap_values4=np.abs(shap_values[4][:,:,wave]).mean(0)
shap_values5=np.abs(shap_values[5][:,:,wave]).mean(0)
shap_values6=np.abs(shap_values[6][:,:,wave]).mean(0)

time = np.linspace(0,412,412)/500
x_pos = np.linspace(0,206,206)*2/500

weight_counts = {
    "Complete": shap_values0[:206],
    "ACoA": shap_values1[:206],
    "PCoA": shap_values2[:206],
    "PCoAs": shap_values3[:206],
    "ACA, A1": shap_values4[:206],
    "PCA, P1": shap_values5[:206],
    "PCoA & PCA": shap_values6[:206],
    
}
width = 2/500

fig, ax = plt.subplots()

bottom = np.zeros(206)

ax.bar(x_pos, shap_values0[:206], width, label='Complete', bottom=bottom,color=['#008bfb'])
bottom += shap_values0[:206]
ax.bar(x_pos, shap_values1[:206], width, label='ACoA', bottom=bottom,color=['#7471f5'])
bottom += shap_values1[:206]
ax.bar(x_pos, shap_values2[:206], width, label='PCoA', bottom=bottom,color=['#d640c5'])
bottom += shap_values2[:206]
ax.bar(x_pos, shap_values3[:206], width, label='PCoAs', bottom=bottom,color=['#ff007b'])
bottom += shap_values3[:206]
ax.bar(x_pos, shap_values4[:206], width, label='ACA, A1', bottom=bottom,color=['#dc5700'])
bottom += shap_values4[:206]
ax.bar(x_pos, shap_values5[:206], width, label='PCA, P1', bottom=bottom,color=['#439300'])
bottom += shap_values5[:206]
ax.bar(x_pos, shap_values6[:206], width, label='PCoA & PCA', bottom=bottom,color=['#009ea6'])
bottom += shap_values6[:206]

#ax.set_title("Number of penguins with above average body mass")
#ax.legend(loc="upper right")
ax.grid(False)
ax.set_facecolor((1, 1, 1))
ax.set_ylim([0, 0.15])
ax.set_yticks([0, 0.05,0.1,0.15])
ax.set_xticks([])
#ax.set_yticks([])
ax.tick_params(axis='both', which='major', labelsize=20)
ax.spines['right'].set_visible(False)
ax.spines['top'].set_visible(False)

ax2 = ax.twinx()
ax2.plot(time,U_RCCA[0,0,:412],'k')
ax2.grid(False)
ax2.set_facecolor((1, 1, 1))
ax2.set_ylim([-0.02, 0.35])
#ax2.set_yticks([-0.02, 0.1,0.2,0.3])
ax2.set_yticks([])
ax2.set_xticks([])
ax2.tick_params(axis='both', which='major', labelsize=20)
ax2.spines['right'].set_visible(False)
ax2.spines['top'].set_visible(False)
