import os

os.environ['TF_CPP_MIN_LOG_LEVEL']='3'

import numpy as np
import tensorflow as tf
from tensorflow import keras
import matplotlib.pyplot as plt
import cyclefinder as cycf
from sklearn.model_selection import train_test_split
from sklearn.metrics import f1_score
from sklearn import metrics
from sklearn.metrics import RocCurveDisplay
import scipy.io
from keras import backend as K
from keras import regularizers
import random 


DTYPE='float32'
tf.keras.backend.set_floatx(DTYPE)
N_mu=4374
N_variation=7
N_time=550

U_RCCA=[]
U_LCCA=[]
U_RVA=[]
U_LVA=[]
for i in range(0,7):
    name1='Sample/U_RCCA'+str(i+1)+'.npy'
    name2='Sample/U_LCCA'+str(i+1)+'.npy'
    name3='Sample/U_RVA'+str(i+1)+'.npy'
    name4='Sample/U_LVA'+str(i+1)+'.npy'
    RCCA=np.load(name1,allow_pickle=True)
    LCCA=np.load(name2,allow_pickle=True)
    RVA=np.load(name3,allow_pickle=True)
    LVA=np.load(name4,allow_pickle=True)
    U_RCCA.append(RCCA)
    U_LCCA.append(LCCA)
    U_RVA.append(RVA)
    U_LVA.append(LVA)        

pre=[0]
U_RCCA_noise=[]
U_LCCA_noise=[]
U_RVA_noise=[]
U_LVA_noise=[]


for j in range(0,7):
    for i in range(0,4374):
        sample=U_RCCA[j][i][:,0].shape[0]
        amp=np.max(U_RCCA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_RCCA_noise.append(U_RCCA[j][i][:,0]+noise)
        
for j in range(0,7):
    for i in range(0,4374):
        sample=U_LCCA[j][i][:,0].shape[0]
        amp=np.max(U_LCCA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_LCCA_noise.append(U_LCCA[j][i][:,0]+noise)

for j in range(0,7):
    for i in range(0,4374):
        sample=U_RVA[j][i][:,0].shape[0]
        amp=np.max(U_RVA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_RVA_noise.append(U_RVA[j][i][:,0]+noise)

for j in range(0,7):
    for i in range(0,4374):
        sample=U_LVA[j][i][:,0].shape[0]
        amp=np.max(U_LVA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_LVA_noise.append(U_LVA[j][i][:,0]+noise)
        
 
U_Root=np.load('Sample/U_Articroot.npy',allow_pickle=True)
time=1/500

def indexfinder(data_noise,data,wave):
    index_vi=np.where(U_Root[wave][:,0]==np.min(U_Root[wave][:,0]))[0][0]
    ddata=np.gradient(data,time)
    asign = np.sign(ddata)
    signchange = ((np.roll(asign, 1) - asign) != 0).astype(int)
    index_signchange=np.where(signchange==1)[0]
    for i in range(1,len(index_signchange)):
        if data[index_signchange[i]+1]-data[index_signchange[i]-1]<0:
            Vsr=data[index_signchange[i]]
            Tsr=index_signchange[i]*time
            break
    
    
    Ved=data_noise[0]
    Vm=np.mean(data_noise)
    Vs=np.max(data_noise)
    Vi=data_noise[index_vi]
    
    Ted=len(data)*time
    Ts=np.where(data==np.max(data))[0][0]*time
    Ti=index_vi*time
    return np.array([Vs,Vsr,Vi,Ved,Vm,Ts,Tsr,Ti,Ted])

U_RCCA_indices=np.zeros([N_variation,N_mu,9])
U_LCCA_indices=np.zeros([N_variation,N_mu,9])
U_RVA_indices=np.zeros([N_variation,N_mu,9])
U_LVA_indices=np.zeros([N_variation,N_mu,9])

counter=0
for i in range(0,7):
    for j in range(0,N_mu):
        U_RCCA_indices[i,j,:]=indexfinder(U_RCCA_noise[counter],U_RCCA[i][j][:,0],j)
        U_LCCA_indices[i,j,:]=indexfinder(U_LCCA_noise[counter],U_LCCA[i][j][:,0],j)
        U_RVA_indices[i,j,:]=indexfinder(U_RVA_noise[counter],U_RVA[i][j][:,0],j)
        U_LVA_indices[i,j,:]=indexfinder(U_LVA_noise[counter],U_LVA[i][j][:,0],j)
        counter=counter+1


X=np.zeros((N_mu*N_variation,36))
Y=np.zeros((N_mu*N_variation,N_variation))


for i in range(0,7):               
    for j in range(0,N_mu):
        X[j+i*N_mu,:9]=U_RCCA_indices[i,j,:]
        X[j+i*N_mu,9:18]=U_LCCA_indices[i,j,:]
        X[j+i*N_mu,18:27]=U_RVA_indices[i,j,:]
        X[j+i*N_mu,27:]=U_LVA_indices[i,j,:]
        Y[j+i*N_mu,i]=1


x_train, x_test, y_train, y_test = train_test_split(X, Y, test_size=0.2)


def recall_m(y_true, y_pred):
    true_positives = K.sum(K.round(K.clip(y_true * y_pred, 0, 1)))
    possible_positives = K.sum(K.round(K.clip(y_true, 0, 1)))
    recall = true_positives / (possible_positives + K.epsilon())
    return recall

def precision_m(y_true, y_pred):
    true_positives = K.sum(K.round(K.clip(y_true * y_pred, 0, 1)))
    predicted_positives = K.sum(K.round(K.clip(y_pred, 0, 1)))
    precision = true_positives / (predicted_positives + K.epsilon())
    return precision

def f1_m(y_true, y_pred):
    precision = precision_m(y_true, y_pred)
    recall = recall_m(y_true, y_pred)
    return 2*((precision*recall)/(precision+recall+K.epsilon()))


model = tf.keras.Sequential()
# convolutional layer
model.add(tf.keras.Input(shape=(x_train.shape[1])))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(10, activation='relu'))
model.add(tf.keras.layers.Dense(y_train.shape[1], activation='Softmax'))

 
class CustomCallback(keras.callbacks.Callback):
    def on_epoch_end(self, epoch, logs=None):
        if logs.get('accuracy')>=0.995:
            self.model.stop_training = True
            
model.compile(loss='BinaryCrossentropy', metrics=[f1_m], optimizer='adam')

model.fit(x_train, y_train, batch_size=1024, epochs=1000,validation_data=(x_test, y_test),verbose=2)


import shap
from matplotlib.cm import ScalarMappable
import matplotlib as mlp
import seaborn as sns
import pandas as pd
explainer = shap.DeepExplainer(model, x_train[:3000])
shap_values = explainer.shap_values(x_test[:300])


shap.summary_plot(shap_values, x_test[:300],
                 class_names= ['Complete', 'ACoA', 'PCoA','PCoAs','ACA, A1','PCA, P1','PCoA & PCA'],
                 feature_names=['$C_r-V_s$', '$C_r-V_{sr}$', '$C_r-V_i$','$C_r-V_{ed}$', '$C_r-V_m$', '$C_r-T_s$','$C_r-T_{sr}$', '$C_r-T_i$', '$C_r-T_{cc}$','$C_l-V_s$', '$C_l-V_{sr}$', '$C_l-V_{i}$','$C_l-V_{ed}$', '$C_l-V_m$', '$C_l-T_s$','$C_l-T_{sr}$', '$C_l-T_i$', '$C_l-T_{cc}$','$V_r-V_s$', '$V_r-V_{sr}$', '$V_r-V_i$','$V_r-V_{ed}$', '$V_r-V_m$', '$V_r-T_s$','$V_r-T_{sr}$', '$V_r-T_i$', '$V_r-T_{cc}$','$V_l-V_s$', '$V_l-V_{sr}$', '$V_l-V_{i}$','$V_l-V_{ed}$', '$V_l-V_m$', '$V_l-T_s$','$V_l-T_{sr}$', '$V_l-T_i$', '$V_l-T_{cc}$'  ])




