import os

os.environ['TF_CPP_MIN_LOG_LEVEL']='3'

import numpy as np
import tensorflow as tf
from sklearn.model_selection import train_test_split
from sklearn.metrics import f1_score
from sklearn import metrics
from sklearn.metrics import RocCurveDisplay
import scipy.io
from sklearn.linear_model import LogisticRegression
from sklearn.naive_bayes import GaussianNB
from sklearn.svm import SVC
from sklearn.pipeline import make_pipeline
from sklearn.preprocessing import StandardScaler
from sklearn.ensemble import GradientBoostingClassifier
from sklearn.ensemble import RandomForestClassifier
import random 


DTYPE='float32'
tf.keras.backend.set_floatx(DTYPE)
N_mu=4374
N_variation=7
N_time=550
Type='RF'




U_RCCA=[]
U_LCCA=[]
U_RVA=[]
U_LVA=[]
for i in range(0,7):
    name1='Sample/U_RCCA'+str(i+1)+'.npy'
    name2='Sample/U_LCCA'+str(i+1)+'.npy'
    name3='Sample/U_RVA'+str(i+1)+'.npy'
    name4='Sample/U_LVA'+str(i+1)+'.npy'
    RCCA=np.load(name1,allow_pickle=True)
    LCCA=np.load(name2,allow_pickle=True)
    RVA=np.load(name3,allow_pickle=True)
    LVA=np.load(name4,allow_pickle=True)
    U_RCCA.append(RCCA)
    U_LCCA.append(LCCA)
    U_RVA.append(RVA)
    U_LVA.append(LVA)        

pre=[0]
U_RCCA_noise=[]
U_LCCA_noise=[]
U_RVA_noise=[]
U_LVA_noise=[]


for j in range(0,7):
    for i in range(0,4374):
        sample=U_RCCA[j][i][:,0].shape[0]
        amp=np.max(U_RCCA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_RCCA_noise.append(U_RCCA[j][i][:,0]+noise)
        
for j in range(0,7):
    for i in range(0,4374):
        sample=U_LCCA[j][i][:,0].shape[0]
        amp=np.max(U_LCCA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_LCCA_noise.append(U_LCCA[j][i][:,0]+noise)

for j in range(0,7):
    for i in range(0,4374):
        sample=U_RVA[j][i][:,0].shape[0]
        amp=np.max(U_RVA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_RVA_noise.append(U_RCCA[j][i][:,0]+noise)

for j in range(0,7):
    for i in range(0,4374):
        sample=U_LVA[j][i][:,0].shape[0]
        amp=np.max(U_LVA[j][i][:,0])
        noise = ((amp*np.random.choice(pre, size=1))/100/1000)*np.asarray(random.sample(range(0,1000),sample)) 
        U_LVA_noise.append(U_LVA[j][i][:,0]+noise)
        
 
U_Root=np.load('Sample/U_Articroot.npy',allow_pickle=True)
time=1/500

def indexfinder(data_noise,data,wave):
    index_vi=np.where(U_Root[wave][:,0]==np.min(U_Root[wave][:,0]))[0][0]
    ddata=np.gradient(data,time)
    asign = np.sign(ddata)
    signchange = ((np.roll(asign, 1) - asign) != 0).astype(int)
    index_signchange=np.where(signchange==1)[0]
    for i in range(1,len(index_signchange)):
        if data[index_signchange[i]+1]-data[index_signchange[i]-1]<0:
            Vsr=data[index_signchange[i]]
            Tsr=index_signchange[i]*time
            break
    
    
    Ved=data_noise[0]
    Vm=np.mean(data_noise)
    Vs=np.max(data_noise)
    Vi=data_noise[index_vi]
    
    Ted=len(data)*time
    Ts=np.where(data==np.max(data))[0][0]*time
    Ti=index_vi*time
    return np.array([Vs,Vsr,Vi,Ved,Vm,Ts,Tsr,Ti,Ted])

U_RCCA_indices=np.zeros([N_variation,N_mu,9])
U_LCCA_indices=np.zeros([N_variation,N_mu,9])
U_RVA_indices=np.zeros([N_variation,N_mu,9])
U_LVA_indices=np.zeros([N_variation,N_mu,9])

counter=0
for i in range(0,7):
    for j in range(0,N_mu):
        U_RCCA_indices[i,j,:]=indexfinder(U_RCCA_noise[counter],U_RCCA[i][j][:,0],j)
        U_LCCA_indices[i,j,:]=indexfinder(U_RCCA_noise[counter],U_LCCA[i][j][:,0],j)
        U_RVA_indices[i,j,:]=indexfinder(U_RCCA_noise[counter],U_RVA[i][j][:,0],j)
        U_LVA_indices[i,j,:]=indexfinder(U_RCCA_noise[counter],U_LVA[i][j][:,0],j)
        counter=counter+1



X=np.zeros((N_mu*N_variation,36))
Y=np.zeros((N_mu*N_variation))


for i in range(0,7):               
    for j in range(0,N_mu):
        X[j+i*N_mu,:9]=U_RCCA_indices[i,j,:]
        X[j+i*N_mu,9:18]=U_LCCA_indices[i,j,:]
        X[j+i*N_mu,18:27]=U_RVA_indices[i,j,:]
        X[j+i*N_mu,27:]=U_LVA_indices[i,j,:]
        Y[j+i*N_mu]=i+1


x_train, x_test, y_train, y_test = train_test_split(X, Y, test_size=0.2)

if Type=='LR':
    clf = LogisticRegression(random_state=0).fit(x_train, y_train)
    print(f1_score(y_test, clf.predict(x_test), average='macro'))
elif Type=='NB':
    clf = GaussianNB()
    clf.fit(x_train, y_train)
    print(f1_score(y_test, clf.predict(x_test), average='macro'))
elif Type=='SVM':
    clf = make_pipeline(StandardScaler(), SVC(gamma='scale'))
    clf.fit(x_test, y_test)
    print(f1_score(y_test, clf.predict(x_test), average='macro'))
elif Type=='GB':
    clf = GradientBoostingClassifier(n_estimators=100, learning_rate=0.1,
        max_depth=5, random_state=0).fit(x_train, y_train)
    print(f1_score(y_test, clf.predict(x_test), average='macro'))
elif Type=='RF':
    clf = RandomForestClassifier(max_depth=5, random_state=0)
    clf.fit(x_test, y_test)
    print(f1_score(y_test, clf.predict(x_test), average='macro'))


